@@ -1,6 +1,9 @@
+import os
 from .direct_estimator import DirectEstimator
 from .transformers import CutTransformer
 
 from ._version import __version__
 
 __all__ = ['DirectEstimator', '__version__']
+
+path = os.path.dirname(__file__)
